<template>
	<div>
		<el-form ref="ruleFormRef" :model="ruleForm" status-icon label-width="20px" class="topTitle">
			<el-row>
				<el-col :span="4">
					<el-form-item size="default">
						<el-input v-model="ruleForm.searchParams.jobId" placeholder="请选择岗位">
							<template #append> <el-button :icon="Search" @click="openSearch" /> </template
						></el-input>
					</el-form-item>
				</el-col>
				<!-- <el-col :span="4">
				<el-form-item>
					<el-input v-model="ruleForm.checkPass" placeholder="目标指标编号" />
				</el-form-item>
			</el-col> -->
				<el-col :span="4">
					<el-form-item>
						<el-button size="default" type="primary" @click="listApi">查询</el-button>
						<el-button size="default" @click="resetForm">重置</el-button>
					</el-form-item>
				</el-col>
			</el-row>
		</el-form>
		<div class="minCenter">
			<div class="btns">
				<div>
					<el-button size="default" type="primary" :icon="Plus" @click="openD('新建')">新建</el-button>
					<el-button size="default" :disabled="warning" type="warning" plain :icon="EditPen">修改</el-button>
					<el-button size="default" :disabled="danger" type="danger" :icon="Delete" plain @click="onDeleteAll">删除</el-button>
				</div>
				<div>
					<!-- <el-button size="default" :icon="Download"></el-button>
					<el-button size="default" :icon="Refresh"></el-button> -->
				</div>
			</div>
			<el-table ref="multipleTableRef" :data="tableData" @selection-change="handleSelectionChange" style="width: 100%">
				<el-table-column type="selection" align="center" width="55" />
				<el-table-column type="index" label="序号" align="center" width="70" />
				<el-table-column property="jobId" align="center" label="岗位" sortable />
				<el-table-column property="signDate" align="center" label="责任书签订日期" :formatter="timeDate" sortable />
				<el-table-column property="extraFile" align="center" label="附件" sortable />
				<el-table-column property="memo" label="备注信息" align="center" sortable show-overflow-tooltip />
				<el-table-column label="操作" align="center" style="width: 300px">
					<template #default="scope">
						<el-button link type="primary" size="default" :icon="View" @click="openD('查看', scope.row.id)">查看</el-button>
						<el-button link type="primary" size="default" :icon="EditPen" @click="openD('修改', scope.row.id)">修改</el-button>
						<el-button link type="primary" size="default" :icon="Delete" @click="onDelete(scope.row.id)">删除</el-button>
					</template>
				</el-table-column>
			</el-table>
			<div class="pages">
				<el-pagination
					v-model:currentPage="currentPage4"
					v-model:page-size="pageSize4"
					:page-sizes="[10, 20, 30, 40]"
					layout="total, sizes, prev, pager, next, jumper"
					:total="total"
					@size-change="handleSizeChange"
					@current-change="handleCurrentChange"
				/>
			</div>
			<DailogAdd ref="openAdd" @navAddorUpdata="onAddorUpdata"></DailogAdd>
			<DailogSearch ref="openUser"></DailogSearch>
		</div>
	</div>
</template>
<script lang="ts">
import DailogAdd from './component/DailogAdd.vue';
import {timeDate} from '/@/assets/index.ts'
import DailogSearch from './component/DailogSearch.vue';
import { ref, toRefs, reactive, onMounted, defineComponent } from 'vue';
import { ElMessageBox, ElMessage, ElButton, ElInput, TabsPaneContext, FormInstance } from 'element-plus';
import { Plus, Delete, Upload, Download, Refresh, View, EditPen, Search } from '@element-plus/icons-vue';
import { goalManagementApi } from '/@/api/goalManagement';
import type { TableColumnCtx } from 'element-plus/es/components/table/src/table-column/defaults';
export default defineComponent({
	components: { ElButton, ElInput, DailogAdd, DailogSearch },
	setup() {
		// 搜索条件
		const ruleForm = reactive({
			pageSize: 10,
			pageIndex: 1,
			searchParams: {
				jobId: '', ////岗位号/外键
			},
		});
		// 重置
		const resetForm = () => {
			ruleForm.searchParams.jobId = '';
			listApi();
		};
		const listApi = () => {
			goalManagementApi()
				.gettargetDutyfileInfoList(ruleForm)
				.then((res) => {
					if (res.data.code == 200) {
						tableData.value = res.data.data;
						currentPage4.value = res.data.pageIndex;
						pageSize4.value = res.data.pageSize;
						total.value = res.data.total;
					} else {
						ElMessage.error(res.data.msg);
					}
				});
		};
		//
		const handleClick = (val: any) => {
			let targetType = JSON.parse(JSON.stringify(val));
			ruleForm.searchParams.jobId = targetType.paneName;
			listApi();
		};
		onMounted(() => {
			listApi();
		});
		const onAddorUpdata = () => {
			listApi();
		};
		// 表格
		const tableData = ref();
		const currentPage4 = ref();
		const pageSize4 = ref();
		const total = ref();
		const handleSizeChange = (val: number) => {
			// console.log(`${val} items per page`);
			ruleForm.pageSize = val;
			listApi();
		};
		const handleCurrentChange = (val: number) => {
			// console.log(`current page: ${val}`);
			ruleForm.pageIndex = val;
			listApi();
		};
		// 弹窗
		const openAdd = ref();
		const openD = (title: String, id: number) => {
			openAdd.value.openDailog(title, ruleForm.searchParams.jobId, id);
		};
		// 删除
		const onDelete = (id: number) => {
			let arr=[]
			arr.push(id)
			ElMessageBox.confirm('确定删除所选项吗?', 'Warning', {
				confirmButtonText: '确定',
				cancelButtonText: '取消',
				type: 'warning',
			})
				.then(() => {
					goalManagementApi()
						.gettargetDutyfileInfoDelete(arr)
						.then((res) => {
							if (res.data.code == 200) {
								ElMessage({
									message: res.data.msg,
									type: 'success',
								});
								listApi();
							} else {
								ElMessage.error(res.data.msg);
							}
						});
				})
				.catch(() => {
					ElMessage({
						type: 'info',
						message: 'Delete canceled',
					});
				});
		};
		// 批量删除
		const warning = ref(true);
		const danger = ref(true);
		const deletAll = ref();
		const handleSelectionChange = (val: any) => {
			let valId = JSON.parse(JSON.stringify(val));
			let arr = [];
			for (let i = 0; i < valId.length; i++) {
				arr.push(valId[i].id);
			}
			deletAll.value = arr
			if (val.length == 1) {
				warning.value = false;
				danger.value = false;
			} else if (val.length == 0) {
				warning.value = true;
				danger.value = true;
			} else {
				warning.value = true;
				danger.value = false;
			}
		};
		const onDeleteAll = () => {
			ElMessageBox.confirm('确定删除所选项吗?', 'Warning', {
				confirmButtonText: '确定',
				cancelButtonText: '取消',
				type: 'warning',
			})
				.then(() => {
					goalManagementApi()
						.gettargetDutyfileInfoDelete(deletAll.value)
						.then((res) => {
							if (res.data.code == 200) {
								ElMessage({
									message: res.data.msg,
									type: 'success',
								});
								listApi();
							} else {
								ElMessage.error(res.data.msg);
							}
						});
				})
				.catch(() => {
					// ElMessage({
					// 	type: 'info',
					// 	message: 'Delete canceled',
					// });
				});
		};
		const openUser = ref();
		const openSearch = () => {
			openUser.value.openDailog();
		};
		return {
			ruleForm,
			resetForm,
			listApi,
			handleClick,
			onAddorUpdata,
			tableData,
			currentPage4,
			pageSize4,
			total,
			handleSizeChange,
			handleCurrentChange,
			openAdd,
			openD,
			onDelete,
			warning,
			danger,
			deletAll,
			handleSelectionChange,
			onDeleteAll,
			openUser,
			openSearch,
			timeDate,
			Plus,
			Delete,
			Upload,
			Download,
			Refresh,
			View,
			EditPen,
			Search,
		};
	},
});
</script>
<style scoped>
.minCenter {
	width: 100%;
	background-color: #fff;
	margin-top: 10px;
	padding: 0 20px;
}
.topTitle {
	background-color: #fff;
	padding: 20px 0px 20px 0px;
	margin-bottom: 10px;
}
.btns {
	padding: 10px 0px 10px 0px;
	display: flex;
	justify-content: space-between;
}
.pages {
	padding: 20px 0;
	display: flex;
	justify-content: right;
}
</style>